/******************************************************************************
 *
 * $Workfile: main.c
 * $Revision:
 * $Date: 25 Aug 2015
 *
 * $Module Description:
 *
 * $Revision History:
 *
 * $Log
 * 
 * 
 * Initial version
 *

*******************************************************************************/
#include <stdio.h>
#include <pic18f4550.h>
#include "Types.h"
#include "gui.h"
#include "LCD_drv.h"
#include "comic.h"
#include "utm.h"

/*****************************************************************************
 Compiler compatibility check
*****************************************************************************/

/*****************************************************************************
 MCU Configurations
*****************************************************************************/
#pragma config FOSC     = HSPLL_HS /*Oscillator Selection */
#pragma config IESO     = OFF /*Internal/External Oscillator Switchover bit */
#pragma config PLLDIV   = 5 // 5 for 20Mhz clock, 12 for 48 Mhz clock
#pragma config CPUDIV   = OSC1_PLL2
#pragma config USBDIV   = 2 /* USB clock Source should be 2*/
#pragma config FCMEN    = ON
#pragma config VREGEN   = ON /* USB regulator voltage */
#pragma config PWRT     = OFF //Power up timer
#pragma config MCLRE    = ON /* master clear enabled */
#pragma config PBADEN   = ON /* AD on port B <4:0> */
#pragma config ICPRT    = OFF /* in circuit debug pins enabled */
#pragma config XINST    = OFF /* extended instruction set enambled */
#pragma config DEBUG    = ON /* enable background debugger */
#pragma config WDT      = OFF /* watch dog timer setting */
#pragma config LVP      = OFF /* Low Voltage Programming setting */
#pragma  config BOR     = OFF
#pragma  config CCP2MX  = OFF
#pragma  config LPT1OSC = OFF
#pragma  config STVREN  = ON
#pragma  config CP0     = OFF
#pragma  config CP1     = OFF
#pragma  config CP2     = OFF
#pragma  config WRT1    = OFF
#pragma  config WRT2    = OFF
#pragma  config WRT3    = OFF

/*****************************************************************************
 Defines
*****************************************************************************/

/*****************************************************************************
 * GUI library callback
*****************************************************************************/
void AppDraw( void );

/*****************************************************************************
 Private types
*****************************************************************************/

/*****************************************************************************
 Private configuration variables
*****************************************************************************/

/*****************************************************************************
 Local variables
*****************************************************************************/
static float        Counter = 0;
static uint8        CirclePos = 5;
static byte         StringDisp[24];
static GUI_DATA     LcdMemBuf[LCD_BUF_SIZE];
static MEMDEV       LcdHandle;
 
 
/*****************************************************************************
 Private helpers forward declaration
*****************************************************************************/
static void DevInit(void);
static void main_draw( void );

/*****************************************************************************
 Implementations
*****************************************************************************/
void main(void)
{
    /* Board hardware initialization */
    PortInit();
    
    /* GUI library initialization */
    GUI_Init( &LcdHandle, LcdMemBuf, LCD_BUF_SIZE );
    
    /* set font color background */
    GUI_SetFontBackColor( ClrDarkRed );
    
    /* Set font */
    GUI_SetFont( (const char *)(&FONT_COMIC_10[0]) );
    
    for(;;)
    { 
        Counter+=0.001;

        if( Counter > 256 )
        {
                Counter = 0;
        }

        CirclePos++;

        if( CirclePos > 120 )
        {
            CirclePos = 15;
        }

        sprintf( StringDisp, "%.3f", Counter );
        
        /* Call GUI library draw */
        GUI_Draw( );
    }
}

void AppDraw( void )
{
    /* GUI drwaing at here */
    GUI_Clear( ClrGreen );
    GUI_DrawFilledRect( 0, 0, 128, 20, ClrBlue );
    GUI_ShowBmp( bmpUTM, 30, 45 );
    GUI_DrawCircle( CirclePos, CirclePos, 5, ClrRed );
    GUI_SetFontBackColor( ClrBlue );
    GUI_PrintString( "LCD Test", ClrYellow, 30, 2 );
    GUI_SetFontBackColor( ClrGreen );
    GUI_PrintString( StringDisp, ClrBlack, 50, 25 );
    
}

/*****************************************************************************
 IRQ handler
*****************************************************************************/

/*****************************************************************************
 Local functions
*****************************************************************************/